@@ -8,6 +8,7 @@ from time import time, sleep
 from functools import partial
 from contextlib import contextmanager
 
+from pika.exceptions import ChannelClosed
 from what import What
 
 from kuyruk import Kuyruk
@@ -24,15 +25,18 @@ logger = logging.getLogger(__name__)
 
 def delete_queue(*queues):
     """Delete queues from RabbitMQ"""
-    with Kuyruk().channel() as channel:
-        for name in queues:
-            RabbitQueue(name, channel).delete()
+    for name in queues:
+        try:
+            ch = Kuyruk().channel()
+            RabbitQueue(name, ch).delete()
+            ch.close()
+        except ChannelClosed:
+            pass
 
 
 def is_empty(queue):
-    with Kuyruk().channel() as channel:
-        queue = RabbitQueue(queue, channel)
-        return len(queue) == 0
+    queue = RabbitQueue(queue, Kuyruk().channel())
+    return len(queue) == 0
 
 
 @contextmanager
